@@ -6,7 +6,7 @@ use warnings;
 
 package Test::Deep::NoTest;
 
-use vars qw( $NoTest );
+our $NoTest;
 
 {
   local $NoTest = 1;
@@ -18,6 +18,7 @@ sub import {
   # make the stack look like it should for use Test::Deep
   my $pkg = shift;
   unshift(@_, "Test::Deep");
+  push @_, '_notest';
   goto &$import;
 }
 
@@ -31,9 +32,9 @@ Test::Deep::NoTest - Use Test::Deep outside of the testing framework
 
   use Test::Deep::NoTest;
 
-  if eq_deeply($a, $b) {
+  if (eq_deeply($a, $b)) {
     print "they were deeply equal\n";
-  };
+  }
 
 =head1 DESCRIPTION
 
